#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const cross_spawn_1 = __importDefault(require("cross-spawn"));
const update_notifier_1 = __importDefault(require("update-notifier"));
const create_1 = require("./command/create");
const notifier = (0, update_notifier_1.default)({
    pkg: require('../package.json'),
    updateCheckInterval: 1000 * 60 * 60, // 1hr
});
notifier.notify({
    defer: false,
    message: `Update available ${chalk_1.default.dim('{currentVersion}')} ${chalk_1.default.reset(' → ')} ${chalk_1.default.green('{latestVersion}')} \nRun ${chalk_1.default.cyan('yarn add {packageName}')} to update.`,
});
(async (cmd) => {
    const [command, ...options] = cmd;
    if (['build', 'dev', 'test'].includes(command)) {
        const result = cross_spawn_1.default.sync(process.execPath, [require.resolve(`./command/${command}`), ...options], {
            stdio: 'inherit',
        });
        return process.exit(result.status);
    }
    if (command === 'create') {
        await (0, create_1.createTemplate)(options[0]);
        return process.exit(0);
    }
    console.log(`${chalk_1.default.red('Commando não reconhecido:')} ${chalk_1.default.yellow(command)}`);
    process.exit(1);
})(process.argv.slice(2));
//# sourceMappingURL=bin.js.map