"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.tryGitCommit = exports.tryGitInit = exports.shouldUseYarn = exports.validProjectName = exports.projectNameInput = exports.templateDependencies = exports.templateFolder = void 0;
const path_1 = __importDefault(require("path"));
const cross_spawn_1 = __importDefault(require("cross-spawn"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const inquirer_1 = __importDefault(require("inquirer"));
const validate_npm_package_name_1 = __importDefault(require("validate-npm-package-name"));
exports.templateFolder = path_1.default.resolve(__dirname, '../../template');
exports.templateDependencies = [
    'react',
    'react-dom',
    'typescript',
    'react-router-dom',
    '@types/react',
    '@types/react-dom',
    '@types/react-router-dom',
    'styled-components',
    '@types/styled-components',
    '@captalys-platform/core',
    '@captalys-platform/scripts',
    '@captalys-platform/eslint-config-captalys-platform',
    'audit-ci',
];
function projectNameInput() {
    return inquirer_1.default.prompt({
        type: 'input',
        name: 'inputName',
        message: 'Nome do Projeto: ',
        validate: (query) => {
            const [result, reason] = validProjectName(query);
            return result || `Nome Invalido: ${reason}`;
        },
    });
}
exports.projectNameInput = projectNameInput;
function validProjectName(appName) {
    const validationResult = (0, validate_npm_package_name_1.default)(appName);
    if (!validationResult.validForNewPackages) {
        return [false, 'npm naming restrictions'];
    }
    if (exports.templateDependencies.includes(appName)) {
        return [false, 'dependency with the same name exists'];
    }
    if (fs_extra_1.default.existsSync(appName)) {
        const currentDirectory = process.cwd();
        const files = fs_extra_1.default.readdirSync(path_1.default.resolve(currentDirectory, appName));
        return files.length === 0 ? [true] : [false, `folder with the same name exist in ${currentDirectory}`];
    }
    return [true];
}
exports.validProjectName = validProjectName;
function shouldUseYarn() {
    try {
        cross_spawn_1.default.sync('yarnpkg', ['--version']);
        return true;
    }
    catch (e) {
        return false;
    }
}
exports.shouldUseYarn = shouldUseYarn;
function tryGitInit() {
    try {
        cross_spawn_1.default.sync('git', ['init'], { stdio: 'ignore' });
        return true;
    }
    catch (e) {
        return false;
    }
}
exports.tryGitInit = tryGitInit;
function tryGitCommit(appPath) {
    try {
        cross_spawn_1.default.sync('git', ['add', '-A'], { stdio: 'ignore' });
        cross_spawn_1.default.sync('git', ['commit', '-m', 'chore: project started'], {
            stdio: 'ignore',
        });
        return true;
    }
    catch (e) {
        try {
            fs_extra_1.default.removeSync(path_1.default.join(appPath, '.git'));
        }
        catch (removeErr) {
            // Do nothing
        }
        return false;
    }
}
exports.tryGitCommit = tryGitCommit;
//# sourceMappingURL=helper.js.map