"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createDevServer = void 0;
process.env.BABEL_ENV = 'development';
process.env.NODE_ENV = 'development';
// Makes the script crash on unhandled rejections instead of silently
// ignoring them. In the future, promise rejections that are not handled will
// terminate the Node.js process with a non-zero exit code.
process.on('unhandledRejection', (err) => {
    throw err;
});
const fs_1 = __importDefault(require("fs"));
const chalk_1 = __importDefault(require("react-dev-utils/chalk"));
const checkRequiredFiles_1 = __importDefault(require("react-dev-utils/checkRequiredFiles"));
const WebpackDevServerUtils_1 = require("react-dev-utils/WebpackDevServerUtils");
const deepmerge_1 = __importDefault(require("deepmerge"));
const webpack_1 = __importDefault(require("webpack"));
const webpack_dev_server_1 = __importDefault(require("webpack-dev-server"));
const env_1 = require("../config/env");
const paths_1 = __importDefault(require("../config/paths"));
const shared_1 = require("../config/shared");
const webpack_config_1 = __importDefault(require("../config/webpack.config"));
const webpackDevServer_config_1 = __importDefault(require("../config/webpackDevServer.config"));
async function createDevServer(paths, userConfig = shared_1.defaultDevConfig) {
    var _a;
    const useCustomConfig = fs_1.default.existsSync(paths.appCustomConfig);
    const { configureWebpack, ...customConfig } = useCustomConfig
        ? deepmerge_1.default.all([shared_1.defaultDevConfig, userConfig, (_a = require(paths.appCustomConfig)) !== null && _a !== void 0 ? _a : {}])
        : Object.assign(shared_1.defaultDevConfig, userConfig);
    const { port: devPort, host: devHost, ...devOptions } = customConfig;
    // We attempt to use the default port but if it is busy, we offer the user to
    // run on a different port. `choosePort()` Promise resolves to the next free port.
    const PORT = await (0, WebpackDevServerUtils_1.choosePort)(devHost, devPort);
    if (PORT == null) {
        // We have not found a port.
        return;
    }
    try {
        // Warn and crash if required files are missing
        if (!(0, checkRequiredFiles_1.default)([paths.appHtml, paths.appIndexJs])) {
            process.exit(1);
        }
        const baseConfig = (0, webpack_config_1.default)('development', paths, devOptions);
        const config = configureWebpack && typeof configureWebpack === 'function'
            ? configureWebpack(baseConfig, 'development')
            : baseConfig;
        const tscCompileOnError = process.env.TSC_COMPILE_ON_ERROR === 'true';
        const protocol = process.env.HTTPS === 'true' ? 'https' : 'http';
        const urls = (0, WebpackDevServerUtils_1.prepareUrls)(protocol, devHost, PORT, paths.publicUrlOrPath.slice(0, -1));
        const devSocket = {
            warnings: (warnings) => 
            // eslint-disable-next-line no-use-before-define
            devServer.sockWrite(devServer.sockets, 'warnings', warnings),
            errors: (errors) => 
            // eslint-disable-next-line no-use-before-define
            devServer.sockWrite(devServer.sockets, 'errors', errors),
        };
        const appName = require(paths.appPackageJson).name;
        // Create a webpack compiler that is configured with custom messages.
        const compiler = (0, WebpackDevServerUtils_1.createCompiler)({
            appName,
            config,
            devSocket,
            urls,
            useYarn: true,
            useTypeScript: true,
            tscCompileOnError,
            webpack: webpack_1.default,
        });
        // Load proxy config
        const proxySetting = require(paths.appPackageJson).proxy;
        const proxyConfig = (0, WebpackDevServerUtils_1.prepareProxy)(proxySetting, paths.appPublic, paths.publicUrlOrPath);
        // Serve webpack assets generated by the compiler over a web server.
        const serverConfig = (0, webpackDevServer_config_1.default)(proxyConfig, urls.lanUrlForConfig, paths);
        const devServer = new webpack_dev_server_1.default(compiler, serverConfig);
        // Launch WebpackDevServer.
        devServer.listen(PORT, devHost, (err) => {
            if (err) {
                return console.log(err);
            }
            if (useCustomConfig) {
                console.log(`${chalk_1.default.cyan('Using custom config from:')} ${chalk_1.default.yellow(paths.appCustomConfig)}\n`);
            }
            console.log(chalk_1.default.cyan('Starting the development server...\n'));
        });
        ['SIGINT', 'SIGTERM'].forEach((sig) => {
            process.on(sig, () => {
                devServer.close();
                process.exit();
            });
        });
    }
    catch (err) {
        if (err && err.message) {
            console.log(err.message);
        }
        process.exit(1);
    }
}
exports.createDevServer = createDevServer;
if (require.main === module) {
    (0, env_1.getEnviroment)(paths_1.default);
    createDevServer(paths_1.default);
}
//# sourceMappingURL=dev.js.map