"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const chalk_1 = __importDefault(require("react-dev-utils/chalk"));
const resolve_1 = __importDefault(require("resolve"));
const paths_1 = __importDefault(require("./paths"));
// Check if TypeScript is setup
const ts = require(resolve_1.default.sync('typescript', {
    basedir: paths_1.default.appNodeModules,
}));
/**
 * Get additional module paths based on the baseUrl of a compilerOptions object.
 *
 * @param {Object} options
 */
function getAdditionalModulePaths(options = {}) {
    const { baseUrl } = options;
    if (!baseUrl) {
        return '';
    }
    const baseUrlResolved = path_1.default.resolve(paths_1.default.appPath, baseUrl);
    // We don't need to do anything if `baseUrl` is set to `node_modules`. This is
    // the default behavior.
    if (path_1.default.relative(paths_1.default.appNodeModules, baseUrlResolved) === '') {
        return null;
    }
    // Allow the user set the `baseUrl` to `appSrc`.
    if (path_1.default.relative(paths_1.default.appSrc, baseUrlResolved) === '') {
        return [paths_1.default.appSrc];
    }
    // If the path is equal to the root directory we ignore it here.
    // We don't want to allow importing from the root directly as source files are
    // not transpiled outside of `src`. We do allow importing them with the
    // absolute path (e.g. `src/Components/Button.js`) but we set that up with
    // an alias.
    if (path_1.default.relative(paths_1.default.appPath, baseUrlResolved) === '') {
        return null;
    }
    // Otherwise, throw an error.
    throw new Error(chalk_1.default.red.bold("Your project's `baseUrl` can only be set to `src` or `node_modules`." +
        ' Create React App does not support other values at this time.'));
}
/**
 * Get webpack aliases based on the baseUrl of a compilerOptions object.
 *
 * @param {*} options
 */
function getWebpackAliases(options = {}) {
    const { baseUrl } = options;
    if (!baseUrl) {
        return {};
    }
    const baseUrlResolved = path_1.default.resolve(paths_1.default.appPath, baseUrl);
    if (path_1.default.relative(paths_1.default.appPath, baseUrlResolved) === '') {
        return {
            src: paths_1.default.appSrc,
        };
    }
}
/**
 * Get jest aliases based on the baseUrl of a compilerOptions object.
 *
 * @param {*} options
 */
function getJestAliases(options = {}) {
    const { baseUrl } = options;
    if (!baseUrl) {
        return {};
    }
    const baseUrlResolved = path_1.default.resolve(paths_1.default.appPath, baseUrl);
    if (path_1.default.relative(paths_1.default.appPath, baseUrlResolved) === '') {
        return {
            '^src/(.*)$': '<rootDir>/src/$1',
        };
    }
}
function getModules() {
    const config = ts.readConfigFile(paths_1.default.appTsConfig, ts.sys.readFile).config || {};
    const options = config.compilerOptions || {};
    const additionalModulePaths = getAdditionalModulePaths(options);
    return {
        additionalModulePaths,
        webpackAliases: getWebpackAliases(options),
        jestAliases: getJestAliases(options),
        hasTsConfig: true,
    };
}
exports.default = getModules();
//# sourceMappingURL=modules.js.map