"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createAppPaths = exports.moduleFileExtensions = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const getPublicUrlOrPath_1 = __importDefault(require("react-dev-utils/getPublicUrlOrPath"));
exports.moduleFileExtensions = [
    'web.mjs',
    'mjs',
    'web.js',
    'js',
    'web.ts',
    'ts',
    'web.tsx',
    'tsx',
    'json',
    'web.jsx',
    'jsx',
];
function createAppPaths(basePath = process.cwd()) {
    var _a;
    const appDirectory = fs_1.default.realpathSync(basePath);
    const resolveApp = (relativePath) => path_1.default.resolve(appDirectory, relativePath);
    const appPackageJson = resolveApp('package.json');
    const publicUrlOrPath = (0, getPublicUrlOrPath_1.default)(process.env.NODE_ENV === 'development', require(appPackageJson).homepage, process.env.PUBLIC_URL);
    // Resolve file paths in the same order as webpack
    const resolveModule = (resolveFn, filePath) => {
        const extension = exports.moduleFileExtensions.find((ext) => fs_1.default.existsSync(resolveFn(`${filePath}.${ext}`)));
        if (extension) {
            return resolveFn(`${filePath}.${extension}`);
        }
        return resolveFn(`${filePath}.js`);
    };
    const appCustomConfig = resolveApp('scriptsrc.js');
    const customConfigExist = fs_1.default.existsSync(appCustomConfig);
    const appBuildFile = customConfigExist ? (_a = require(appCustomConfig)) === null || _a === void 0 ? void 0 : _a.output : 'build';
    const appBuildPath = appBuildFile || 'build';
    return {
        dotenv: resolveApp('.env'),
        appPath: resolveApp('.'),
        appBuild: resolveApp(appBuildPath),
        appPublic: resolveApp('public'),
        appHtml: resolveApp('public/index.html'),
        appIndexJs: resolveModule(resolveApp, 'src/index'),
        appSrc: resolveApp('src'),
        appTsConfig: resolveApp('tsconfig.json'),
        yarnLockFile: resolveApp('yarn.lock'),
        testsSetup: resolveModule(resolveApp, 'src/setupTests'),
        proxySetup: resolveApp('src/setupProxy.js'),
        appNodeModules: resolveApp('node_modules'),
        appCustomConfig,
        appPackageJson,
        publicUrlOrPath,
        moduleFileExtensions: exports.moduleFileExtensions,
    };
}
exports.createAppPaths = createAppPaths;
exports.default = createAppPaths();
//# sourceMappingURL=paths.js.map