"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const errorOverlayMiddleware_1 = __importDefault(require("react-dev-utils/errorOverlayMiddleware"));
const evalSourceMapMiddleware_1 = __importDefault(require("react-dev-utils/evalSourceMapMiddleware"));
const ignoredFiles_1 = __importDefault(require("react-dev-utils/ignoredFiles"));
const noopServiceWorkerMiddleware_1 = __importDefault(require("react-dev-utils/noopServiceWorkerMiddleware"));
const redirectServedPathMiddleware_1 = __importDefault(require("react-dev-utils/redirectServedPathMiddleware"));
exports.default = (proxy, allowedHost, paths) => {
    const host = process.env.HOST || '0.0.0.0';
    const sockHost = process.env.WDS_SOCKET_HOST;
    const sockPath = process.env.WDS_SOCKET_PATH; // default: '/sockjs-node'
    const sockPort = process.env.WDS_SOCKET_PORT;
    return {
        disableHostCheck: !proxy || process.env.DANGEROUSLY_DISABLE_HOST_CHECK === 'true',
        compress: true,
        clientLogLevel: 'none',
        contentBase: paths.appPublic,
        contentBasePublicPath: paths.publicUrlOrPath,
        watchContentBase: true,
        hot: true,
        transportMode: 'ws',
        injectClient: false,
        sockHost,
        sockPath,
        sockPort,
        publicPath: paths.publicUrlOrPath.slice(0, -1),
        quiet: true,
        watchOptions: {
            ignored: (0, ignoredFiles_1.default)(paths.appSrc),
        },
        host,
        overlay: false,
        historyApiFallback: {
            disableDotRule: true,
            index: paths.publicUrlOrPath,
        },
        public: allowedHost,
        proxy,
        before(app, server) {
            app.use((0, evalSourceMapMiddleware_1.default)(server));
            app.use((0, errorOverlayMiddleware_1.default)());
            // We will not use proxy i guess
            if (fs_1.default.existsSync(paths.proxySetup)) {
                require(paths.proxySetup)(app);
            }
        },
        after(app) {
            app.use((0, redirectServedPathMiddleware_1.default)(paths.publicUrlOrPath));
            app.use((0, noopServiceWorkerMiddleware_1.default)(paths.publicUrlOrPath));
        },
    };
};
//# sourceMappingURL=webpackDevServer.config.js.map